const { withXcodeProject } = require("@expo/config-plugins");
const fs = require("fs");
const path = require("path");

module.exports = function withExcludedArchitecturesConfig(config) {
	return withXcodeProject(config, (config) => {
		try {
			const project = config.modResults;
			const xcconfigFilename = "ExcludedArchitectures.xcconfig";

			const platformProjectRoot = config.modRequest.platformProjectRoot;

			if (!platformProjectRoot) {
				throw new Error(
					"platformProjectRoot is undefined. Cannot determine iOS project path.",
				);
			}

			const xcconfigPath = path.join(platformProjectRoot, xcconfigFilename);

			const excludedArchitecturesSetting =
				"EXCLUDED_ARCHS[sdk=iphonesimulator*] = arm64";

			if (!fs.existsSync(xcconfigPath)) {
				fs.writeFileSync(
					xcconfigPath,
					`${excludedArchitecturesSetting}\n`,
					"utf8",
				);
			} else {
				let xcconfigContent = fs.readFileSync(xcconfigPath, "utf8");

				if (!xcconfigContent.includes(excludedArchitecturesSetting)) {
					xcconfigContent += `\n${excludedArchitecturesSetting}\n`;
					fs.writeFileSync(xcconfigPath, xcconfigContent, "utf8");
				} else {
					console.log(
						`${xcconfigFilename} already contains the excluded architectures setting.`,
					);
				}
			}

			const buildConfigs = project.pbxXCBuildConfigurationSection();

			for (const key of Object.keys(buildConfigs)) {
				if (key.startsWith("/*") || key.startsWith("//") || key.trim() === "") {
					continue;
				}

				const buildConfig = buildConfigs[key];
				if (buildConfig.buildSettings) {
					if (!buildConfig.buildSettings.BASE_CONFIGURATION_FILE) {
						buildConfig.buildSettings.BASE_CONFIGURATION_FILE = `"${xcconfigFilename}"`;
					} else {
						if (
							!buildConfig.buildSettings.BASE_CONFIGURATION_FILE.includes(
								xcconfigFilename,
							)
						) {
							buildConfig.buildSettings.BASE_CONFIGURATION_FILE += ` "${xcconfigFilename}"`;
						}
					}
				}
			}

			return config;
		} catch (error) {
			console.error(
				"Error in withExcludedArchitecturesXcconfig plugin:",
				error,
			);
			throw error;
		}
	});
};
